/*
** Module   : PaintStructure.java
** Abstract : A structure used to store paint parameters.
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 MAG 20140508 First version.
** 002 MAG 20140912 Add fillPoly parameters.
** 003 EVL 20141116 Adding round rectangles draw and fill.
** 004 EVL 20141125 Adding dotted line draw capability.
** 005 EVL 20150203 Adding image offset options.
*/

package com.goldencode.p2j.ui.client.gui.driver.swing;

import java.awt.*;

/**
 * A structure used to store paint parameters. Depending on paint operation different fields are
 * used.
 */
public class PaintStructure
{
   /** Paint operation */
   PaintPrimitives id;
   
   /** X parameter */
   int x;
   
   /** Y parameter */
   int y;
   
   /** Width parameter */
   int width;
   
   /** Height parameter */
   int height;
   
   /** X offset to start drawing image. */
   int xOffset;
   
   /** Y offset to start drawing image. */
   int yOffset;
   
   /** Diameter of the arc at the four corner. */
   int arcDiameter;
   
   /** Polygon X coordinates */
   int[] xPoints;
   
   /** Polygon Y coordinates */
   int[] yPoints;
   
   /** Polygon number of coordinates */
   int nPoints;
      
   /** Raised parameter for 3D operations */
   boolean raised;
   
   /** Font parameter */
   Font font;
   
   /** Color parameter */
   Color color;
   
   /** Text to draw */
   String text;
   
   /** Image to draw */
   Image img;

   /** Pattern to draw the lines. */
   Stroke stroke;

   /**
    * Constructor.
    * 
    * @param   id
    *          Paint operation id.
    */
   public PaintStructure(PaintPrimitives id)
   {
      this.id = id;
   }
}
